# daylight-factor

Daylight factor recipe for Pollination

Use this recipe to calculate daylight factor for a Honeybee model or zipped
honeybee-radiance folder.

You can only use a Honeybee model when using the `-viz` tag.
